/*
*
* Star Rating component written with Stencil.js
* by Aaron Sterling
* https://github.com/Aaron-Sterling/star-rating-stencil
*
*/
export class StarRating {
    constructor() {
        this.initialRating = 0;
        this.fontSize = 25;
        this.stars = 5;
        this.color = 'gold';
        this._starCounter = new Array();
    }
    componentWillLoad() {
        this.firstRun();
    }
    firstRun() {
        this.backupOriginalProps();
        this.initializeInternalState();
        console.log(this.stars);
    }
    backupOriginalProps() {
        this._initialRatingOriginal = this.initialRating;
        this._fontSizeOriginal = this.fontSize;
        this._numberOfStarsOriginal = this.stars;
        this._colorOriginal = this.color;
    }
    initializeInternalState() {
        this._fontSizeExpression = this.fontSize.toString() + 'px';
        this.currentRating = this.initialRating;
        this._starCounter = new Array(this.stars).fill(true);
    }
    propsHaveChanged() {
        return !(this.initialRating === this._initialRatingOriginal &&
            this.fontSize === this._fontSizeOriginal &&
            this.color === this._colorOriginal &&
            this.stars === this._numberOfStarsOriginal);
    }
    componentDidLoad() {
        if (this.propsHaveChanged) {
            this.firstRun();
        }
    }
    render() {
        return (h("span", null, this._starCounter.map((_, currentIndex) => h("ion-icon", { name: this.iconName(currentIndex + 1), onClick: _ => this.updateRating(currentIndex + 1), style: { 'font-size': this._fontSizeExpression, 'color': this.color } }))));
    }
    updateRating(rating) {
        this.currentRating = rating;
        this.newRating.emit(rating);
    }
    iconName(starNumber) {
        const threshold = this.currentRating - starNumber;
        if (threshold >= 0) {
            return 'star';
        }
        else {
            return 'star-outline';
        }
        ;
    }
    static get is() { return "star-rating"; }
    static get encapsulation() { return "shadow"; }
    static get properties() { return { "color": { "type": String, "attr": "color" }, "currentRating": { "state": true }, "fontSize": { "type": Number, "attr": "font-size" }, "initialRating": { "type": Number, "attr": "initial-rating" }, "stars": { "type": Number, "attr": "stars" } }; }
    static get events() { return [{ "name": "newRating", "method": "newRating", "bubbles": true, "cancelable": true, "composed": true }]; }
    static get style() { return "/**style-placeholder:star-rating:**/"; }
}
